@@ -24,7 +24,7 @@ def get_k8s_ns() -> Optional[str]:
     if _K8S_NS == _not_set:
         if os.path.exists(NAMESPACE_FILEPATH):
             with open(NAMESPACE_FILEPATH) as fi:
-                _K8S_NS = fi.read()
+                _K8S_NS = fi.read().strip()
         else:
             _K8S_NS = None
     return _K8S_NS  # type: ignore
@@ -65,7 +65,9 @@ class PydanticStreamHandler(logging.StreamHandler):
 
 class KafkaeskQueue:
     def __init__(
-        self, app: kafkaesk.app.Application, max_queue: int = 10000,
+        self,
+        app: kafkaesk.app.Application,
+        max_queue: int = 10000,
     ):
         self._queue: Optional[asyncio.Queue] = None
         self._queue_size = max_queue
@@ -81,7 +83,7 @@ class KafkaeskQueue:
             self._queue = asyncio.Queue(maxsize=self._queue_size)
 
         if self._task is None or self._task.done():
-            self._task = asyncio.get_event_loop().create_task(self._run())
+            self._task = asyncio.create_task(self._run())
 
     def close(self) -> None:
         if self._task is not None and not self._task._loop.is_closed():
@@ -124,15 +126,9 @@ class KafkaeskQueue:
         if not self._app._initialized:
             await self._app.initialize()
 
-        try:
-            await self._app.publish(stream, log_data)
-        except kafkaesk.exceptions.UnregisteredSchemaException:
-            self._print_to_stderr("Log schema is not registered", log_data)
+        await self._app.publish(stream, log_data)
         # TODO: Handle other Kafak errors that may be raised
 
-    def _print_to_stderr(self, error: str, log_data: PydanticLogModel) -> None:
-        sys.stderr.write(f"Error sending log to Kafka: \n{error}\nMessage: {log_data.json()}")
-
     def put_nowait(self, stream: str, log_data: PydanticLogModel) -> None:
         if self._queue is not None:
             self._queue.put_nowait((stream, log_data))
@@ -173,7 +169,7 @@ class PydanticKafkaeskHandler(logging.Handler):
             record.exc_text = _formatter.formatException(record.exc_info)
             try:
                 record.exc_type = record.exc_info[0].__name__  # type: ignore
-            except (AttributeError, IndexError):
+            except (AttributeError, IndexError):  # pragma: no cover
                 ...
 
         if record.stack_info:
@@ -205,20 +201,31 @@ class PydanticKafkaeskHandler(logging.Handler):
         extra_logs: Dict[str, Any] = {}
 
         for log in getattr(record, "pydantic_data", []):
-            extra_logs.update(log.dict(exclude_none=True, exclude={"_is_log_model",},))
+            extra_logs.update(
+                log.dict(
+                    exclude_none=True,
+                    exclude={
+                        "_is_log_model",
+                    },
+                )
+            )
 
         return extra_logs
 
     def emit(self, record: PydanticLogRecord) -> None:  # type: ignore
         if not self._queue.running:
-            self._queue.start()
+            try:
+                self._queue.start()
+            except RuntimeError:
+                sys.stderr.write("RuntimeError starting kafka logging, ignoring")
+                return
 
         try:
             raw_data = self._format_base_log(record)
             raw_data.update(self._format_extra_logs(record))
             log_data = PydanticLogModel(**raw_data)
             self._queue.put_nowait(self.stream, log_data)
-        except InvalidLogFormat:
+        except InvalidLogFormat:  # pragma: no cover
             sys.stderr.write("PydanticKafkaeskHandler recieved non-pydantic model")
         except RuntimeError:
             sys.stderr.write("Queue No event loop running to send log to Kafka\n")
@@ -226,7 +233,7 @@ class PydanticKafkaeskHandler(logging.Handler):
             if time.time() - self._last_warning_sent > 30:
                 sys.stderr.write("Queue hit max log queue size, discarding message\n")
                 self._last_warning_sent = time.time()
-        except AttributeError:
+        except AttributeError:  # pragma: no cover
             sys.stderr.write("Queue Error sending Kafkaesk log message\n")
 
     def close(self) -> None:
